@@ -6,8 +6,6 @@
 // email:    support@MOSEK.com
 //-----------------------------------------------------------------------------
 
-// This code is licensed under the terms of the Eclipse Public License (EPL).
-
 #ifndef OsiMskSolverInterface_H
 #define OsiMskSolverInterface_H
 
@@ -85,8 +83,6 @@ public:
     virtual bool isDualObjectiveLimitReached() const;
     /// Iteration limit reached?
     virtual bool isIterationLimitReached() const;
-    /// Has there been a license problem?
-    virtual bool isLicenseError() const;
   //@}
 
   //---------------------------------------------------------------------------
@@ -251,12 +247,6 @@ public:
       /** Get as many dual rays as the solver can provide. (In case of proven
           primal infeasibility there should be at least one.)
      
-	  The first getNumRows() ray components will always be associated with
-	  the row duals (as returned by getRowPrice()). If \c fullRay is true,
-	  the final getNumCols() entries will correspond to the ray components
-	  associated with the nonbasic variables. If the full ray is requested
-	  and the method cannot provide it, it will throw an exception.
-
           <strong>NOTE for implementers of solver interfaces:</strong> <br>
           The double pointers in the vector should point to arrays of length
           getNumRows() and they should be allocated via new[]. <br>
@@ -265,8 +255,7 @@ public:
           It is the user's responsibility to free the double pointers in the
           vector using delete[].
       */
-      virtual std::vector<double*> getDualRays(int maxNumRays,
-					       bool fullRay=false) const;
+      virtual std::vector<double*> getDualRays(int maxNumRays) const;
       /** Get as many primal rays as the solver can provide. (In case of proven
           dual infeasibility there should be at least one.)
      
@@ -305,11 +294,11 @@ public:
 				  const double* coeffList);
 
       /** Set a single column lower bound<br>
-    	  Use -COIN_DBL_MAX for -infinity. */
+    	  Use -DBL_MAX for -infinity. */
       virtual void setColLower( int elementIndex, double elementValue );
       
       /** Set a single column upper bound<br>
-    	  Use COIN_DBL_MAX for infinity. */
+    	  Use DBL_MAX for infinity. */
       virtual void setColUpper( int elementIndex, double elementValue );
       
       /** Set a single column lower and upper bound<br>
@@ -330,11 +319,11 @@ public:
 				   const double* boundList);
       
       /** Set a single row lower bound<br>
-    	  Use -COIN_DBL_MAX for -infinity. */
+    	  Use -DBL_MAX for -infinity. */
       virtual void setRowLower( int elementIndex, double elementValue );
       
       /** Set a single row upper bound<br>
-    	  Use COIN_DBL_MAX for infinity. */
+    	  Use DBL_MAX for infinity. */
       virtual void setRowUpper( int elementIndex, double elementValue );
     
       /** Set a single row lower and upper bound<br>
@@ -610,13 +599,13 @@ public:
     /// keep all cached data (similar to getMutableLpPtr())
     KEEPCACHED_ALL     = KEEPCACHED_PROBLEM | KEEPCACHED_RESULTS,
     /// free only cached column and LP solution information
-    FREECACHED_COLUMN  = KEEPCACHED_PROBLEM & ~KEEPCACHED_COLUMN,
+    FREECACHED_COLUMN  = KEEPCACHED_PROBLEM & !KEEPCACHED_COLUMN,
     /// free only cached row and LP solution information
-    FREECACHED_ROW     = KEEPCACHED_PROBLEM & ~KEEPCACHED_ROW,
+    FREECACHED_ROW     = KEEPCACHED_PROBLEM & !KEEPCACHED_ROW,
     /// free only cached matrix and LP solution information
-    FREECACHED_MATRIX  = KEEPCACHED_PROBLEM & ~KEEPCACHED_MATRIX,
+    FREECACHED_MATRIX  = KEEPCACHED_PROBLEM & !KEEPCACHED_MATRIX,
     /// free only cached LP solution information
-    FREECACHED_RESULTS = KEEPCACHED_ALL & ~KEEPCACHED_RESULTS
+    FREECACHED_RESULTS = KEEPCACHED_ALL & !KEEPCACHED_RESULTS
   };
 
   MSKtask_t getLpPtr( int keepCached = KEEPCACHED_NONE );
@@ -758,6 +747,8 @@ private:
   /// free all allocated memory
   void freeAllMemory();
 
+  /// Just for testing purposes
+  void printBounds(); 
  /**@name Private member data */
   //@{
   /// MOSEK model represented by this class instance
@@ -831,6 +822,7 @@ private:
 
 //#############################################################################
 /** A function that tests the methods in the OsiMskSolverInterface class */
+
 void OsiMskSolverInterfaceUnitTest(const std::string & mpsDir, const std::string & netlibDir);
 
 #endif
